﻿Public Class FrmMainUser
    ''' <summary>
    ''' Theq query for manipulating the data of the user.
    ''' </summary>
    ''' <remarks>Query for manipulating the data of the user.</remarks>
    Private UserManipQuery As String = ""

    ''' <summary>
    ''' The default id of the selected user from the datagridview.
    ''' </summary>
    ''' <remarks>The id of the selected user from the datagridview.</remarks>
    Private DefaultUserId As Integer = 0

    ''' <summary>
    ''' Enables all disabled controls.
    ''' </summary>
    ''' <param name="Target">The control where the enabling of control will be executed.</param>
    ''' <remarks>Enables all controls in a specific control like (Form, Groupbox etc.).</remarks>
    Private Sub EnableAllControls(ByVal Target As Control)
        For Each Ctrl As Control In Target.Controls
            Ctrl.Enabled = True
        Next
    End Sub

    Private Sub FrmMainUser_FormClosed(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosedEventArgs) Handles Me.FormClosed
        ClearAllFields(GrpUserDetails)
    End Sub

    Private Sub CloseForm(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyEventArgs) Handles Me.KeyDown

        If e.KeyCode.Equals(Keys.Escape) Then
            Me.Close()
        End If
    End Sub

    Private Sub FrmMainUser_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Query("CALL UserGetAll()", DtgUser)
        SetAutoCompletion("CALL UserGetAllUserTypes", ComboUserType)

        If ComboUserType.Items.Contains("admin") Then

            ComboUserType.Items.Remove("admin")
        End If
    End Sub

    Private Sub BtnSave_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles BtnSave.Click

        If ComboUserType.Text.Equals(String.Empty) And _
            TxtFirstname.Text.Equals(String.Empty) And _
            TxtLastname.Text.Equals(String.Empty) And _
            TxtPassword.Text.Equals(String.Empty) Then

            MessageBox.Show("Please fill in all the required details.", PROGRAM_NAME, MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
        Else
            If DefaultUserId.Equals(0) Then
                UserManipQuery = String.Format("CALL UserAdd('{0}', '{1}', '{2}', '{3}', '{4}')", TxtUsername.Text, TxtPassword.Text, LCase(ComboUserType.Text), TxtFirstname.Text, TxtLastname.Text)
                Query("Added new user successfully.", UserManipQuery)

            Else

                UserManipQuery = String.Format("CALL UserUpdate('{0}', '{1}', '{2}', '{3}', '{4}', {5})", TxtUsername.Text, TxtPassword.Text, LCase(ComboUserType.Text), TxtFirstname.Text, TxtLastname.Text, DefaultUserId)
                MsgBox(UserManipQuery)
                Query("Updated user successfully.", UserManipQuery)
            End If

            BtnAddNew.PerformClick()
        End If

        FrmMainUser_Load(sender, e)
    End Sub

    Private Sub BtnAddNew_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles BtnAddNew.Click

        DefaultUserId = 0

        EnableAllControls(GrpUserDetails)
        ClearAllFields(GrpUserDetails)
    End Sub

    Private Sub DtgUser_CellClick(ByVal sender As Object, ByVal e As System.Windows.Forms.DataGridViewCellEventArgs) Handles DtgUser.CellClick

        With DtgUser.CurrentRow
            DefaultUserId = .Cells("id").Value
            ComboUserType.Text = .Cells("Type").Value
            TxtFirstname.Text = .Cells("First Name").Value
            TxtLastname.Text = .Cells("Last Name").Value
            TxtUsername.Text = .Cells("Username").Value
            TxtPassword.Text = GetSingleValue(String.Format("CALL UserGetPassword('{0}')", .Cells("Username").Value))

            If Not UserType.Equals("admin") Then
                If .Cells("Type").Value.Equals("admin") Then
                    For Each Ctrl As Control In GrpUserDetails.Controls

                        If TypeOf Ctrl Is TextBox Then

                            CType(Ctrl, TextBox).Enabled = False
                        ElseIf TypeOf Ctrl Is ComboBox Then

                            CType(Ctrl, ComboBox).Enabled = False
                        ElseIf TypeOf Ctrl Is Button Then

                            CType(Ctrl, Button).Enabled = False
                            If CType(Ctrl, Button).Text.Equals("Add New") Then

                                CType(Ctrl, Button).Enabled = True
                            End If
                        End If
                    Next
                Else

                    EnableAllControls(GrpUserDetails)
                End If
            End If
        End With
    End Sub

    Private Sub TxtFirstname_KeyDown(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyEventArgs) Handles ComboUserType.KeyDown, TxtFirstname.KeyDown, TxtLastname.KeyDown, TxtUsername.KeyDown, TxtPassword.KeyDown

        If e.KeyCode = Keys.Enter Then
            BtnSave.PerformClick()
        End If
    End Sub

    Private Sub DtgUser_DataSourceChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles DtgUser.DataSourceChanged
        Dim Result As String = String.Empty
        For Each Row As DataGridViewRow In DtgUser.Rows

            For Each Letter In Row.Cells("Password").Value
                Result &= "•"
            Next

            Row.Cells("Password").Value = Result
            Result = String.Empty
        Next

    End Sub

    Private Sub ChkShowPass_CheckedChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ChkShowPass.CheckedChanged
        If ChkShowPass.Checked Then
            TxtPassword.UseSystemPasswordChar = False
        Else
            TxtPassword.UseSystemPasswordChar = True
        End If
    End Sub
End Class